# Numerical Algorithms

## [Numerical Stability](http://mathworld.wolfram.com/NumericalStability.html)
 
Numerical stability refers to how a malformed input affects the execution of an 
algorithm. In a numerically stable algorithm, errors in the input lessen in 
significance as the algorithm executes, having little effect on the final 
output.

On the other hand, in a numerically unstable algorithm, errors in the input 
cause a considerably larger error in the final output.

## [Interpolation](https://en.wikipedia.org/wiki/Interpolation#Example)

- [Linear interpolation](https://en.wikipedia.org/wiki/Linear_interpolation)

- [Polynomial interpolation](https://en.wikipedia.org/wiki/Polynomial_interpolation)

   Polynomial interpolation is the interpolation of a given data set by a 
[polynomial](https://en.wikipedia.org/wiki/Polynomial): given some points, find 
a polynomial which goes exactly through these points.

  - [Lagrange form](https://en.wikipedia.org/wiki/Lagrange_polynomial)

  - [Newton polynomial](https://en.wikipedia.org/wiki/Newton_polynomial)